<?php
/*
* getNumThread.php
* http://tasuke.dna.affrc.go.jp/
*
* Author: Daiki Nishikawa
*
* Copyright (c) 2013 National Institute of Agrobiological Sciences
*
*/

require '../conf/config.php';

// Parameters
(isset($_POST['effver']) && !empty($_POST['effver'])) ? $prm_effver=$_POST['effver']:_stopError("||Invalid value");
$effcol = $prm_effver."col";
echo ${$effcol};

function _stopError($str){
    echo $str;
    exit;
}
?>
